Transform

Trait Transform 

pub trait Transform<H> {
    type Output;

    // Required method
    fn transform(&self, h: H) -> Self::Output;
}
Then Transform trait defines the interface of a handler factory that wraps inner handler to a Handler during construction.

Required Associated Types

type Output

A new handler.

Required Methods

fn transform(&self, h: H) -> Self::Output

Transforms self and wraps Handler to a new handler.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<H, S, G, V> Transform<H> for viz_core::middleware::csrf::Config<S, G, V>

Available on crate feature csrf only.
Source

type Output = CsrfMiddleware<H, S, G, V>

Source

impl<H, S, G, V> Transform<H> for viz_core::middleware::session::Config<S, G, V>

Available on crate feature session only.
Source

impl<H, T> Transform<H> for viz_core::middleware::otel::tracing::Config<T>
where T: Clone,

Available on crate features otel-tracing and otel and params only.
Source

impl<H, T> Transform<H> for State<T>
where T: Clone + Send + Sync + 'static,

Available on crate feature state only.
Source

impl<H> Transform<H> for viz_core::middleware::cors::Config

Available on crate feature cors only.
Source

impl<H> Transform<H> for viz_core::middleware::otel::metrics::Config

Available on crate features otel-metrics and otel and params only.
Source

impl<H> Transform<H> for viz_core::middleware::cookie::Config
where H: Clone,

Available on crate feature cookie only.
Source

impl<H> Transform<H> for viz_core::middleware::limits::Config
where H: Clone,

Available on crate feature limits only.
Source

impl<H> Transform<H> for viz_core::middleware::compression::Config
where H: Clone,

Available on crate feature compression only.